Skip to contents

Background functions for QTLretrievR that will be called by the primary functions

Usage

split_map(map, chr_names = NULL)

Arguments

map

grid map of markers, chromosomes, and positions of markers

chr_names

vector of chromosome names