Determine significant and suggestive LOD thresholds
LOD_thld.RdDetermine significant and suggestive LOD thresholds for your QTLs, using
scan1perm from qtl2. Select the number of genes to permute, the number of
permutations, and the number of genes to run in each batch.
Arguments
- mapping
Mapping list from
mapQTL, or full path to.rdscontaining one.- tissue
Tissue to determine thresholds for.
- annots
Data frame of phenotype annotations for filtering to autosomal phenotypes. Columns must include "id", "symbol", "start", "end".
- n.gene
Number of phenotypes to run permutations on. Default is 75.
- n.perm
Number of permutations to run per phenotype. Default is 750.
- batch.size
Number of genes in each parallelized batch.