Background functions for QTLretrievR that will be called by the primary functions
split_map.RdBackground functions for QTLretrievR that will be called by the primary functions

split_map.RdBackground functions for QTLretrievR that will be called by the primary functions